{% extends 'base.html' %}

{% block content %}

<div class="panel panel-default">
    <div class="panel-heading"><h3>Are you sure, you want to disable two-factor authentication?</h3></div>
    <div class="panel-body">

      <form action="." method="POST">
      {% csrf_token %}
      <button class="btn btn-default">Disable two-factor authentication</button>
      </form>

    </div>
  </div>

{% endblock %}